@@ -54,10 +54,10 @@ pub fn upload(
         Some(user) => {
             log::info!("GlobalUser set, running with authentication");
 
-            let missing_fields = validate(&target);
+            let missing_fields = validate(target);
 
             if missing_fields.is_empty() {
-                let client = http::legacy_auth_client(&user);
+                let client = http::legacy_auth_client(user);
 
                 if let Some(site_config) = target.site.clone() {
                     let site_namespace = add_namespace(user, target, true)?;
@@ -73,7 +73,7 @@ pub fn upload(
 
                     bulk::put(target, user, &site_namespace.id, to_upload, &None)?;
 
-                    let preview = authenticated_upload(&client, &target, Some(asset_manifest))?;
+                    let preview = authenticated_upload(&client, target, Some(asset_manifest))?;
                     if !to_delete.is_empty() {
                         if verbose {
                             StdOut::info("Deleting stale files...");
@@ -84,7 +84,7 @@ pub fn upload(
 
                     preview
                 } else {
-                    authenticated_upload(&client, &target, None)?
+                    authenticated_upload(&client, target, None)?
                 }
             } else {
                 StdOut::warn(&format!(
@@ -96,7 +96,7 @@ pub fn upload(
                     anyhow::bail!(SITES_UNAUTH_PREVIEW_ERR)
                 }
 
-                unauthenticated_upload(&target)?
+                unauthenticated_upload(target)?
             }
         }
         None => {
@@ -113,7 +113,7 @@ pub fn upload(
                 anyhow::bail!(SITES_UNAUTH_PREVIEW_ERR)
             }
 
-            unauthenticated_upload(&target)?
+            unauthenticated_upload(target)?
         }
     };
 
