@@ -1,7 +1,9 @@
 use notify::DebouncedEvent;
-use std::path::PathBuf;
-use std::sync::mpsc::Receiver;
-use std::time::Duration;
+use std::{
+    path::PathBuf,
+    sync::mpsc::{Receiver, Sender},
+    time::Duration,
+};
 
 use anyhow::{anyhow, Result};
 
@@ -9,9 +11,18 @@ use crate::terminal::message::{Message, StdOut};
 use log::info;
 
 // Add cooldown for all types of events to watching logic
-pub fn wait_for_changes(rx: &Receiver<DebouncedEvent>, cooldown: Duration) -> Result<PathBuf> {
+pub fn wait_for_changes(
+    rx: &Receiver<DebouncedEvent>,
+    check_channel: Option<Sender<Option<()>>>,
+    cooldown: Duration,
+) -> Result<PathBuf> {
     loop {
         let event = rx.recv()?;
+        // Sending a None to the channel will only succeed if there is a
+        // receiver and return from this fn otherwise
+        if let Some(check_channel) = &check_channel {
+            check_channel.send(None)?;
+        }
         match get_changed_path_from_event(event) {
             Ok(Some(path)) => {
                 StdOut::working("Detected changes...");
